@@ -28,9 +28,8 @@
 #include <QDBusReply>
 #include <QUuid>
 
-#include <KDebug>
-#include <KStandardDirs>
-#include <KLocale>
+#include <QDebug>
+#include <KLocalizedString>
 #include <KMessageBox>
 
 #include <NetworkManagerQt/ConnectionSettings>
@@ -67,8 +66,7 @@ void BluetoothMonitor::addBluetoothConnection(const QString& bdAddr, const QStri
     mService = service.toLower();
     if (mService == "dun") {
 #if WITH_MODEMMANAGER_SUPPORT
-        connect(ModemManager::notifier(), SIGNAL(modemAdded(QString)),
-                SLOT(modemAdded(QString)));
+        connect(ModemManager::notifier(), &ModemManager::Notifier::modemAdded, this, &BluetoothMonitor::modemAdded);
 #endif
     }
     init();
@@ -116,8 +114,8 @@ void BluetoothMonitor::init()
     QDBusReply<QDBusObjectPath> devicePath = adapter.call(QLatin1String("FindDevice"), mBdaddr);
 
     if (!devicePath.isValid()) {
-        kWarning(KDE_DEFAULT_DEBUG_AREA) << mBdaddr << " is not registered in default bluetooth adapter, it may be in another adapter.";
-        kWarning(KDE_DEFAULT_DEBUG_AREA) << mBdaddr << " waiting for it to be registered in ModemManager";
+        qWarning() << mBdaddr << " is not registered in default bluetooth adapter, it may be in another adapter.";
+        qWarning() << mBdaddr << " waiting for it to be registered in ModemManager";
         return;
     }
 
@@ -199,8 +197,8 @@ void BluetoothMonitor::init()
         return;
     } else if (mService != QLatin1String("dun")) {
         mDunDevice = mService;
-        kWarning(KDE_DEFAULT_DEBUG_AREA) << "device(" << mDunDevice << ") for" << mBdaddr << " passed as argument";
-        kWarning(KDE_DEFAULT_DEBUG_AREA) << "waiting for it to be registered in ModemManager";
+        qWarning() << "device(" << mDunDevice << ") for" << mBdaddr << " passed as argument";
+        qWarning() << "waiting for it to be registered in ModemManager";
         return;
     }
 
