@@ -60,13 +60,13 @@
 #include <QDebug>
 #include <QPushButton>
 
-#include <KIcon>
 #include <KUser>
 #include <KNotification>
 #include <KLocalizedString>
 #include <KPluginFactory>
 #include <KServiceTypeTrader>
-#include <KWallet/Wallet>
+#include <KWallet/KWallet>
+#include <KIconLoader>
 
 ConnectionDetailEditor::ConnectionDetailEditor(const NetworkManager::ConnectionSettings::Ptr& connection,
                                                bool newConnection, QWidget* parent, Qt::WindowFlags f)
@@ -195,11 +195,11 @@ void ConnectionDetailEditor::initTabs()
         m_ui->tabWidget->addTab(wiredSecurity, i18n("802.1x Security"));
     } else if (type == NetworkManager::ConnectionSettings::Wireless) {
         WifiConnectionWidget * wifiWidget = new WifiConnectionWidget(m_connection->setting(NetworkManager::Setting::Wireless), this);
-        m_ui->tabWidget->addTab(wifiWidget, i18n("Wireless"));
+        m_ui->tabWidget->addTab(wifiWidget, i18n("Wi-Fi"));
         WifiSecurity * wifiSecurity = new WifiSecurity(m_connection->setting(NetworkManager::Setting::WirelessSecurity),
                                                        m_connection->setting(NetworkManager::Setting::Security8021x).staticCast<NetworkManager::Security8021xSetting>(),
                                                        this);
-        m_ui->tabWidget->addTab(wifiSecurity, i18n("Wireless Security"));
+        m_ui->tabWidget->addTab(wifiSecurity, i18n("Wi-Fi Security"));
     } else if (type == NetworkManager::ConnectionSettings::Pppoe) { // DSL
         PppoeWidget * pppoeWidget = new PppoeWidget(m_connection->setting(NetworkManager::Setting::Pppoe), this);
         m_ui->tabWidget->addTab(pppoeWidget, i18n("DSL"));
@@ -385,7 +385,7 @@ void ConnectionDetailEditor::replyFinished(QDBusPendingCallWatcher *watcher)
         notification->setComponentName("networkmanagement");
         notification->setTitle(i18n("Failed to get secrets for %1", watcher->property("connection").toString()));
         notification->setText(reply.error().message());
-        notification->setPixmap(KIcon("dialog-warning").pixmap(64, 64));
+        notification->setPixmap(QIcon::fromTheme("dialog-warning").pixmap(KIconLoader::SizeHuge));
         notification->sendEvent();
 
         connect(this, SIGNAL(accepted()), notification, SLOT(close()));
