@@ -26,14 +26,13 @@
 #include <NetworkManagerQt/Setting>
 
 #include "settingwidget.h"
-#include "plasmanm_export.h"
 
 namespace Ui
 {
 class InfinibandWidget;
 }
 
-class PLASMA_NM_EXPORT InfinibandWidget : public SettingWidget
+class Q_DECL_EXPORT InfinibandWidget : public SettingWidget
 {
     Q_OBJECT
 public:
