@@ -22,8 +22,9 @@
 #include "ui_wificonnectionwidget.h"
 
 #include <NetworkManagerQt/Utils>
+#include <KLocalizedString>
 
-#include <KDebug>
+#include <QDebug>
 
 #include "uiutils.h"
 
@@ -59,14 +60,14 @@ void WifiConnectionWidget::loadConfig(const NetworkManager::Setting::Ptr &settin
 {
     NetworkManager::WirelessSetting::Ptr wifiSetting = setting.staticCast<NetworkManager::WirelessSetting>();
 
-    m_ui->SSIDCombo->init(QString::fromUtf8(wifiSetting->ssid()));
+    m_ui->SSIDCombo->init(wifiSetting->ssid());
 
     if (wifiSetting->mode() != NetworkManager::WirelessSetting::Infrastructure) {
         m_ui->modeComboBox->setCurrentIndex(wifiSetting->mode());
     }
     modeChanged(wifiSetting->mode());
 
-    m_ui->BSSIDCombo->init(NetworkManager::Utils::macAddressAsString(wifiSetting->bssid()), QString::fromUtf8(wifiSetting->ssid()));
+    m_ui->BSSIDCombo->init(NetworkManager::Utils::macAddressAsString(wifiSetting->bssid()), wifiSetting->ssid());
 
     m_ui->band->setCurrentIndex(wifiSetting->band());
     if (wifiSetting->band() != NetworkManager::WirelessSetting::Automatic) {
@@ -177,7 +178,7 @@ void WifiConnectionWidget::fillChannels(NetworkManager::WirelessSetting::Frequen
     } else if (band == NetworkManager::WirelessSetting::Bg) {
         channels = NetworkManager::Utils::getBFreqs();
     } else {
-        kWarning() << "Unhandled band number" << band;
+        qWarning() << "Unhandled band number" << band;
         return;
     }
 
