@@ -20,7 +20,7 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 #include "simpleipv4addressvalidator.h"
 
-#include <KDebug>
+#include <QDebug>
 #include <QStringList>
 
 SimpleIpV4AddressValidator::SimpleIpV4AddressValidator(QObject *parent)
@@ -64,7 +64,7 @@ QValidator::State SimpleIpV4AddressValidator::checkTetradsRanges(QString &value,
     foreach(const QString &part, addrParts) {
         if (part.isEmpty()) {
             if (i != (addrParts.size() - 1)) {
-                //kDebug() << "part.isEmpty()";
+                //qDebug() << "part.isEmpty()";
                 return QValidator::Invalid;
             }
             // the last tetrad can be empty, continue...
@@ -74,7 +74,7 @@ QValidator::State SimpleIpV4AddressValidator::checkTetradsRanges(QString &value,
         tetrads[i] = part.toInt();
 
         if (tetrads[i] > 255) {
-            //kDebug() << "tetrads[i] > 255";
+            //qDebug() << "tetrads[i] > 255";
             return QValidator::Invalid;
         }
 
@@ -89,10 +89,11 @@ QValidator::State SimpleIpV4AddressValidator::checkTetradsRanges(QString &value,
 
     if (i < 4) {
         // not all tetrads are filled... continue
-        //kDebug() << "QValidator::Intermediate";
+        //qDebug() << "QValidator::Intermediate";
         return QValidator::Intermediate;
-    } else {
-        //kDebug() << "QValidator::Acceptable";
+    }
+    else {
+        //qDebug() << "QValidator::Acceptable";
         return QValidator::Acceptable;
     }
 }
