@@ -27,8 +27,6 @@
 
 #include <KLocalizedString>
 
-#include <QtAlgorithms>
-
 bool signalCompare(const NetworkManager::AccessPoint::Ptr & one, const NetworkManager::AccessPoint::Ptr & two) {
     return one->signalStrength() > two->signalStrength();
 }
@@ -143,7 +141,7 @@ void BssidComboBox::addBssidsToCombo(const QList<NetworkManager::AccessPoint::Pt
             continue;
         }
 
-        const QString text = i18n("%1 (%2%)\nFrequency: %3 Mhz\nChannel: %4", ap->hardwareAddress(), ap->signalStrength(), ap->frequency(), QString::number(NetworkManager::Utils::findChannel(ap->frequency())));
+        const QString text = QString("%1 (%2%)").arg(ap->hardwareAddress()).arg(ap->signalStrength());
         addItem(text, QVariant::fromValue(ap->hardwareAddress()));
     }
 }
