@@ -58,12 +58,12 @@ QVariant NetworkModel::data(const QModelIndex& index, int role) const
                 return item->connectionPath();
             case ConnectionStateRole:
                 return item->connectionState();
+            case DeviceName:
+                return item->deviceName();
             case DevicePathRole:
                 return item->devicePath();
             case DeviceStateRole:
                 return item->deviceState();
-            case DownloadRole:
-                return item->download();
             case DuplicateRole:
                 return item->duplicate();
             case ItemUniqueNameRole:
@@ -102,8 +102,6 @@ QVariant NetworkModel::data(const QModelIndex& index, int role) const
                 return item->type();
             case UniRole:
                 return item->uni();
-            case UploadRole:
-                return item->upload();
             case UuidRole:
                 return item->uuid();
             case VpnState:
@@ -129,9 +127,9 @@ QHash< int, QByteArray > NetworkModel::roleNames() const
     roles[ConnectionIconRole] = "ConnectionIcon";
     roles[ConnectionPathRole] = "ConnectionPath";
     roles[ConnectionStateRole] = "ConnectionState";
+    roles[DeviceName] = "DeviceName";
     roles[DevicePathRole] = "DevicePath";
     roles[DeviceStateRole] = "DeviceState";
-    roles[DownloadRole] = "Download";
     roles[DuplicateRole] = "Duplicate";
     roles[ItemUniqueNameRole] = "ItemUniqueName";
     roles[ItemTypeRole] = "ItemType";
@@ -149,7 +147,6 @@ QHash< int, QByteArray > NetworkModel::roleNames() const
     roles[TimeStampRole] = "TimeStamp";
     roles[TypeRole] = "Type";
     roles[UniRole] = "Uni";
-    roles[UploadRole] = "Upload";
     roles[UuidRole] = "Uuid";
     roles[VpnState] = "VpnState";
 
@@ -443,8 +440,6 @@ void NetworkModel::addConnection(const NetworkManager::Connection::Ptr& connecti
 
         item->updateDetails();
 
-        connect(item, SIGNAL(itemUpdated()), SLOT(onItemUpdated()));
-
         const int index = m_list.count();
         beginInsertRows(QModelIndex(), index, index);
         m_list.insertItem(item);
@@ -496,8 +491,6 @@ void NetworkModel::addWimaxNsp(const NetworkManager::WimaxNsp::Ptr& nsp, const N
     item->setType(NetworkManager::ConnectionSettings::Wimax);
     item->updateDetails();
 
-    connect(item, SIGNAL(itemUpdated()), SLOT(onItemUpdated()));
-
     const int index = m_list.count();
     beginInsertRows(QModelIndex(), index, index);
     m_list.insertItem(item);
@@ -539,8 +532,6 @@ void NetworkModel::addWirelessNetwork(const NetworkManager::WirelessNetwork::Ptr
     item->setSecurityType(securityType);
     item->updateDetails();
 
-    connect(item, SIGNAL(itemUpdated()), SLOT(onItemUpdated()));
-
     const int index = m_list.count();
     beginInsertRows(QModelIndex(), index, index);
     m_list.insertItem(item);
@@ -567,8 +558,6 @@ void NetworkModel::checkAndCreateDuplicate(const QString& connection, const Netw
         NetworkModelItem * duplicatedItem = new NetworkModelItem(originalItem);
         duplicatedItem->updateDetails();
 
-        connect(duplicatedItem, SIGNAL(itemUpdated()), SLOT(onItemUpdated()));
-
         const int index = m_list.count();
         beginInsertRows(QModelIndex(), index, index);
         m_list.insertItem(duplicatedItem);
