@@ -57,14 +57,11 @@ NetworkModelItem::NetworkModelItem(QObject* parent)
     , m_connectionState(NetworkManager::ActiveConnection::Deactivated)
     , m_deviceState(NetworkManager::Device::UnknownState)
     , m_duplicate(false)
-    , m_engine(0)
-    , m_dataEngineConsumer(new Plasma::DataEngineConsumer)
     , m_mode(NetworkManager::WirelessSetting::Infrastructure)
     , m_securityType(NetworkManager::Utils::None)
     , m_signal(0)
     , m_slave(false)
     , m_type(NetworkManager::ConnectionSettings::Unknown)
-    , m_updateEnabled(false)
     , m_vpnState(NetworkManager::VpnConnection::Unknown)
 {
 }
@@ -74,8 +71,6 @@ NetworkModelItem::NetworkModelItem(const NetworkModelItem* item, QObject* parent
     , m_connectionPath(item->connectionPath())
     , m_connectionState(NetworkManager::ActiveConnection::Deactivated)
     , m_duplicate(true)
-    , m_engine(0)
-    , m_dataEngineConsumer(new Plasma::DataEngineConsumer)
     , m_mode(item->mode())
     , m_name(item->name())
     , m_securityType(item->securityType())
@@ -120,12 +115,6 @@ NetworkManager::ActiveConnection::State NetworkModelItem::connectionState() cons
 void NetworkModelItem::setConnectionState(NetworkManager::ActiveConnection::State state)
 {
     m_connectionState = state;
-
-    if (m_connectionState == NetworkManager::ActiveConnection::Activated && !m_devicePath.isEmpty()) {
-        initializeDataEngine();
-    } else {
-        removeDataEngine();
-    }
 }
 
 QStringList NetworkModelItem::details() const
@@ -138,6 +127,11 @@ QString NetworkModelItem::devicePath() const
     return m_devicePath;
 }
 
+QString NetworkModelItem::deviceName() const
+{
+    return m_deviceName;
+}
+
 void NetworkModelItem::setDeviceName(const QString& name)
 {
     m_deviceName = name;
@@ -158,12 +152,6 @@ void NetworkModelItem::setDeviceState(const NetworkManager::Device::State state)
     m_deviceState = state;
 }
 
-QString NetworkModelItem::download() const
-{
-    double download = m_download.toDouble();
-    return KLocale::global()->formatByteSize(download*1024) + "/s";
-}
-
 bool NetworkModelItem::duplicate() const
 {
     return m_duplicate;
@@ -416,12 +404,6 @@ QString NetworkModelItem::uni() const
     }
 }
 
-QString NetworkModelItem::upload() const
-{
-    double upload = m_upload.toDouble();
-    return KLocale::global()->formatByteSize(upload*1024) + "/s";
-}
-
 QString NetworkModelItem::uuid() const
 {
     return m_uuid;
@@ -619,58 +601,3 @@ void NetworkModelItem::updateDetails()
     }
 #endif
 }
-
-void NetworkModelItem::dataUpdated(const QString& sourceName, const Plasma::DataEngine::Data& data)
-{
-    if (sourceName == m_uploadSource) {
-        m_upload = data["value"].toString();
-    } else if (sourceName == m_downloadSource) {
-        m_download = data["value"].toString();
-    }
-    Q_EMIT itemUpdated();
-}
-
-void NetworkModelItem::initializeDataEngine()
-{
-    m_engine = m_dataEngineConsumer->dataEngine("systemmonitor");
-
-    NetworkManager::Device::Ptr device = NetworkManager::findNetworkInterface(m_devicePath);
-    if (!device) {
-        removeDataEngine();
-        return;
-    }
-
-    QString interfaceName = device->ipInterfaceName();
-    if (interfaceName.isEmpty()) {
-        interfaceName = device->interfaceName();
-    }
-
-    m_downloadSource = QString("network/interfaces/%1/receiver/data").arg(interfaceName);
-    m_uploadSource = QString("network/interfaces/%1/transmitter/data").arg(interfaceName);
-
-    setUpdateEnabled(true);
-}
-
-void NetworkModelItem::removeDataEngine()
-{
-    setUpdateEnabled(false);
-}
-
-void NetworkModelItem::setUpdateEnabled(bool enabled)
-{
-    Plasma::DataEngine * engine = m_dataEngineConsumer->dataEngine("systemmonitor");
-    NetworkManager::Device::Ptr device = NetworkManager::findNetworkInterface(m_devicePath);
-    if (engine->isValid()) {
-        int interval = 2000;
-        if (enabled) {
-            if (device) {
-                engine->connectSource(m_downloadSource, this, interval);
-                engine->connectSource(m_uploadSource, this, interval);
-            }
-        } else {
-            engine->disconnectSource(m_downloadSource, this);
-            engine->disconnectSource(m_uploadSource, this);
-        }
-    }
-    m_updateEnabled = enabled;
-}
