@@ -23,7 +23,7 @@
 #include "uiutils.h"
 
 // KDE
-#include <KLocale>
+#include <KLocalizedString>
 
 #include <NetworkManagerQt/BluetoothDevice>
 #include <NetworkManagerQt/Manager>
@@ -53,11 +53,8 @@ QString UiUtils::interfaceTypeLabel(const NetworkManager::Device::Type type, con
 {
     QString deviceText;
     switch (type) {
-    case NetworkManager::Device::Ethernet:
-        deviceText = i18nc("title of the interface widget in nm's popup", "Wired Ethernet");
-        break;
     case NetworkManager::Device::Wifi:
-        deviceText = i18nc("title of the interface widget in nm's popup", "Wireless 802.11");
+        deviceText = i18nc("title of the interface widget in nm's popup", "Wi-Fi");
         break;
     case NetworkManager::Device::Bluetooth:
         deviceText = i18nc("title of the interface widget in nm's popup", "Bluetooth");
@@ -104,6 +101,7 @@ QString UiUtils::interfaceTypeLabel(const NetworkManager::Device::Type type, con
         }
     }
         break;
+    case NetworkManager::Device::Ethernet:
     default:
         deviceText = i18nc("title of the interface widget in nm's popup", "Wired Ethernet");
         break;
@@ -157,11 +155,11 @@ QString UiUtils::iconAndTitleForConnectionSettingsType(NetworkManager::Connectio
         icon = "network-wireless";
         break;
     case ConnectionSettings::Wired:
-        text = i18n("Wired");
+        text = i18n("Wired Ethernet");
         icon = "network-wired";
         break;
     case ConnectionSettings::Wireless:
-        text = i18n("Wireless");
+        text = i18n("Wi-Fi");
         icon = "network-wireless";
         break;
 #if NM_CHECK_VERSION(0, 9, 10)
@@ -549,41 +547,6 @@ QString UiUtils::labelFromWirelessSecurity(NetworkManager::Utils::WirelessSecuri
     return tip;
 }
 
-QString UiUtils::shortToolTipFromWirelessSecurity(NetworkManager::Utils::WirelessSecurityType type)
-{
-    QString tip;
-    switch (type) {
-        case NetworkManager::Utils::None:
-            tip = i18nc("@info:tooltip no security", "Insecure");
-            break;
-        case NetworkManager::Utils::StaticWep:
-            tip = i18nc("@info:tooltip WEP security", "WEP");
-            break;
-        case NetworkManager::Utils::Leap:
-            tip = i18nc("@info:tooltip LEAP security", "LEAP");
-            break;
-        case NetworkManager::Utils::DynamicWep:
-            tip = i18nc("@info:tooltip Dynamic WEP security", "Dynamic WEP");
-            break;
-        case NetworkManager::Utils::WpaPsk:
-            tip = i18nc("@info:tooltip WPA-PSK security", "WPA-PSK");
-            break;
-        case NetworkManager::Utils::WpaEap:
-            tip = i18nc("@info:tooltip WPA-EAP security", "WPA-EAP");
-            break;
-        case NetworkManager::Utils::Wpa2Psk:
-            tip = i18nc("@info:tooltip WPA2-PSK security", "WPA2-PSK");
-            break;
-        case NetworkManager::Utils::Wpa2Eap:
-            tip = i18nc("@info:tooltip WPA2-EAP security", "WPA2-EAP");
-            break;
-        default:
-            tip = i18nc("@info:tooltip unknown security", "Unknown security type");
-            break;
-    }
-    return tip;
-}
-
 QString UiUtils::formatDateRelative(const QDateTime & lastUsed)
 {
     QString lastUsedText;
@@ -609,7 +572,7 @@ QString UiUtils::formatDateRelative(const QDateTime & lastUsed)
         } else if (lastUsed.daysTo(now) == 1) {
             lastUsedText = i18nc("Label for last used time for a network connection used the previous day", "Yesterday");
         } else {
-            lastUsedText = KLocale::global()->formatDate(lastUsed.date(), KLocale::ShortDate);
+            lastUsedText = QLocale().toString(lastUsed.date(), QLocale::ShortFormat);
         }
     } else {
         lastUsedText =  i18nc("Label for last used time for a "
@@ -643,7 +606,7 @@ QString UiUtils::formatLastUsedDateRelative(const QDateTime & lastUsed)
         } else if (lastUsed.daysTo(now) == 1) {
             lastUsedText = i18nc("Label for last used time for a network connection used the previous day", "Last used yesterday");
         } else {
-            lastUsedText = i18n("Last used on %1", KLocale::global()->formatDate(lastUsed.date(), KLocale::ShortDate));
+            lastUsedText = i18n("Last used on %1", QLocale().toString(lastUsed.date(), QLocale::ShortFormat));
         }
     } else {
         lastUsedText =  i18nc("Label for last used time for a "
