@@ -25,9 +25,7 @@
 #include "openswanwidget.h"
 #include "openswanauth.h"
 
-
-K_PLUGIN_FACTORY(OpenswanUiPluginFactory, registerPlugin<OpenswanUiPlugin>(); )
-K_EXPORT_PLUGIN(OpenswanUiPluginFactory("plasmanetworkmanagement_openswanui"))
+K_PLUGIN_FACTORY_WITH_JSON(OpenswanUiPluginFactory, "plasmanetworkmanagement_openswanui.json", registerPlugin<OpenswanUiPlugin>(); )
 
 OpenswanUiPlugin::OpenswanUiPlugin(QObject * parent, const QVariantList &):
     VpnUiPlugin(parent)
@@ -77,3 +75,5 @@ bool OpenswanUiPlugin::exportConnectionSettings(const NetworkManager::Connection
     mError = VpnUiPlugin::NotImplemented;
     return false;
 }
+
+#include "openswan.moc"
